## 1.2.2
- Add executable paths to config

## 1.2.1
- Fix aliases

## 1.2.0
- Rename from `goss-gen` to `goss-config-gen`

## 1.1.0
- Added support for generating a config file from existing Gossamer role files

## 1.0.0
- Initial release